@@ -1,9 +1,13 @@
 import asyncio
+import gzip
+import io
 import json
 import logging
 import pickle
+import zlib
 
 import socketio
+import ubjson
 import ujson as ujson
 from multiprocessing.dummy import Pool
 
@@ -30,12 +34,12 @@ class GSCNodeFunctionReceiverSocket:
 
         @self.sio.event
         def oncnodefunction(id, msg):
-            msg1 = pickle.loads(msg)
+            decompressed_byte_data = zlib.decompress(msg)
+            msg1 = ubjson.loadb(decompressed_byte_data)
             if msg1["cnodefunction"] == self.gsdbs.credentials["cnode"]:
-                self._pool.apply_async(self.oncnodefunction, args=[self.gsdbs, id, pickle.loads(msg)],
+                self._pool.apply_async(self.oncnodefunction, args=[self.gsdbs, id, msg1],
                                        callback=on_success,
                                        error_callback=on_errorPost)
-            # self.oncnodefunction(self.gsdbs, id, ujson.loads(msg))
 
         connectURL = ""
 
@@ -114,8 +118,10 @@ class GSCNodeFunctionCaller:
     def emitFunction(self, sio, target, msg):
         # sio.emit("oncnodefunction", {"target": target, "message": ujson.dumps(msg)})
         msg["cnodefunction"] = target
-        data_string = pickle.dumps(msg)
-        sio.emit("oncnodefunction", data_string)
+
+        encoded=ubjson.dumpb(msg)
+        compressed_data =zlib.compress(encoded)
+        sio.emit("oncnodefunction", compressed_data)
 
     def sendcnodefunction(self, target, msg):
         self._pool.apply_async(self.emitFunction, args=[self.sio, target, msg], callback=self.on_success,
